@@ -1,4 +1,4 @@
-from typing import Dict, Iterable, List, Optional, Type
+from typing import List, Optional, Type
 
 import attrs
 import pytest  # type:ignore[import]
@@ -6,7 +6,7 @@ from bo4e.bo.marktlokation import Marktlokation
 from bo4e.bo.messlokation import Messlokation
 
 from bomf.mapper import Bo4eDataSetToTargetMapper, SourceToBo4eDataSetMapper
-from bomf.model import Bo4eTyp, BusinessObjectRelation
+from bomf.model import Bo4eTyp
 
 
 class _NotImplementedBo4eDataSetMixin:
@@ -14,12 +14,6 @@ class _NotImplementedBo4eDataSetMixin:
     a mixin to inherit from if you'd like to have correct types but don't care about the logic
     """
 
-    def get_relations(self) -> Iterable[BusinessObjectRelation]:
-        raise NotImplementedError("Not relevant for this test")
-
-    def get_business_object(self, bo_type: Type[Bo4eTyp], specification: Optional[str] = None) -> Bo4eTyp:
-        raise NotImplementedError("Not relevant for this test")
-
 
 @attrs.define(kw_only=True, auto_attribs=True)
 class _MaLoAndMeLo(_NotImplementedBo4eDataSetMixin):
@@ -44,11 +38,14 @@ class _MaLoAndMeLo(_NotImplementedBo4eDataSetMixin):
 
 
 class _DictToMaLoMeLoMapper(SourceToBo4eDataSetMapper):
-    def create_data_set(self, source: Dict[str, str]) -> _MaLoAndMeLo:
-        return _MaLoAndMeLo(
-            melo=Messlokation.construct(messlokations_id=source["meloId"]),
-            malo=Marktlokation.construct(marktlokations_id=source["maloId"]),
-        )
+    def create_data_sets(self) -> List[_MaLoAndMeLo]:
+        return [
+            _MaLoAndMeLo(
+                melo=Messlokation.construct(messlokations_id=source["meloId"]),
+                malo=Marktlokation.construct(marktlokations_id=source["maloId"]),
+            )
+            for source in [{"maloId": "54321012345", "meloId": "DE000111222333"}]
+        ]
 
 
 class _MaLoMeLoToListMapper(Bo4eDataSetToTargetMapper):
@@ -60,17 +57,9 @@ class _MaLoMeLoToListMapper(Bo4eDataSetToTargetMapper):
 
 
 class TestMapper:
-    def test_source_to_intermediate_mapper(self):
-        mapper = _DictToMaLoMeLoMapper()
-        actual = mapper.create_data_set({"maloId": "54321012345", "meloId": "DE000111222333"})
-        assert actual == _MaLoAndMeLo(
-            melo=Messlokation.construct(messlokations_id="DE000111222333"),
-            malo=Marktlokation.construct(marktlokations_id="54321012345"),
-        )
-
     def test_source_to_intermediate_mapper_batch(self):
         mapper = _DictToMaLoMeLoMapper()
-        actual = mapper.create_data_sets([{"maloId": "54321012345", "meloId": "DE000111222333"}])
+        actual = mapper.create_data_sets()
         assert actual == [
             _MaLoAndMeLo(
                 melo=Messlokation.construct(messlokations_id="DE000111222333"),
